@@ -4,7 +4,7 @@ package DBIx::SearchBuilder;
 use strict;
 use warnings;
 
-our $VERSION = "1.50";
+our $VERSION = "1.51";
 
 use Clone qw();
 use Encode qw();
@@ -1427,13 +1427,19 @@ sub CountAll {
 
     # If we haven't actually got all objects loaded in memory, we
     # really just want to do a quick count from the database.
-    if ( $self->{'must_redo_search'} || !$self->{'count_all'}) {
+    # or if we have paging enabled then we count as well and store it in count_all
+    if ( $self->{'must_redo_search'} || ( $self->RowsPerPage && !$self->{'count_all'} ) ) {
         # If we haven't already asked the database for the row count, do that
-        $self->_DoCount(1) unless ( $self->{'count_all'} );
+        $self->_DoCount(1);
 
         #Report back the raw # of rows in the database
         return ( $self->{'count_all'} );
     }
+    
+    # if we have paging enabled and have count_all then return it
+    elsif ( $self->RowsPerPage ) {
+        return ( $self->{'count_all'} );
+    }
 
     # If we have loaded everything from the DB we have an
     # accurate count already.
