@@ -1,11 +1,11 @@
 # $Header: /home/jesse/DBIx-SearchBuilder/history/SearchBuilder/Handle/mysql.pm,v 1.8 2001/10/12 05:27:05 jesse Exp $
 
 package DBIx::SearchBuilder::Handle::mysql;
-use DBIx::SearchBuilder::Handle;
-@ISA = qw(DBIx::SearchBuilder::Handle);
 
-use vars qw($VERSION @ISA $DBIHandle $DEBUG);
 use strict;
+use warnings;
+
+use base qw(DBIx::SearchBuilder::Handle);
 
 =head1 NAME
 
@@ -21,9 +21,6 @@ compensates for some of the idiosyncrasies of MySQL.
 
 =head1 METHODS
 
-=cut
-
-
 =head2 Insert
 
 Takes a table name as the first argument and assumes that the rest of the arguments are an array of key-value pairs to be inserted.
